## A packaged PyPi application (Artifactory)
 Will create a random number between 2, 100 and calculate all Prime numbers that come before it. package and push to a private PyPi registry (Artifactory)


### Functions
* You'll be able to generate a random number (random.randint) and call `printPrime(number).`
* Otherwise you can call `Prime()` to print an automatically generated number (2, 100)

<hr>

# Usage 
`pip install Optimus-Prime==2.0.1`
